@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
-"""
-This is an example to train a task with DDPG + HER algorithm.
+"""This is an example to train a task with DDPG + HER algorithm.
 
 Here it creates a gym environment FetchReach.
 
@@ -22,7 +21,15 @@ from garage.tf.q_functions import ContinuousMLPQFunction
 
 
 def run_task(snapshot_config, *_):
-    """Run task."""
+    """Run task.
+
+    Args:
+        snapshot_config (garage.experiment.SnapshotConfig): The snapshot
+            configuration used by LocalRunner to create the snapshotter.
+
+        _ (object): Ignored by this function.
+
+    """
     with LocalTFRunner(snapshot_config=snapshot_config) as runner:
         env = TfEnv(gym.make('FetchReach-v1'))
 
@@ -58,11 +65,11 @@ def run_task(snapshot_config, *_):
             qf_lr=1e-3,
             qf=qf,
             replay_buffer=replay_buffer,
-            target_update_tau=0.05,
-            n_epoch_cycles=20,
-            max_path_length=100,
+            target_update_tau=0.01,
+            n_epoch_cycles=50,
+            max_path_length=250,
             n_train_steps=40,
-            discount=0.9,
+            discount=0.95,
             exploration_strategy=action_noise,
             policy_optimizer=tf.train.AdamOptimizer,
             qf_optimizer=tf.train.AdamOptimizer,
